@@ -250,6 +250,7 @@ def parse_iocs(text, defang=False, whitelist_regex='', iocs_to_parse=None,
         whitelist_ip_cidr_ranges = list(csv.reader([whitelist_ip_cidr_ranges]))[0]
     whitelist_ip_cidr_ranges = [ip_network(cidr) for cidr in whitelist_ip_cidr_ranges]
 
+    text, filenames = format_text_without_filepaths(text)
     text2 = urllib.parse.unquote(text)
     text_chunks = set()
     text_versions = [text, text2]
@@ -282,9 +283,15 @@ def parse_iocs(text, defang=False, whitelist_regex='', iocs_to_parse=None,
         text_chunks.update(found)
         text_chunks.update([iocextract.refang_url(x) for x in found])
     if {"ipv4_public", "ipv4_private", "ipv6_public", "ipv6_private"}.intersection(iocs_to_parse):
-        found = list(iocextract.extract_ips(text, refang=False))
-        text_chunks.update(found)
-        text_chunks.update([iocextract.refang_ipv4(x) for x in found])
+        try:
+            found = list(iocextract.extract_ips(text, refang=False))
+            valid_ips = []
+            for ip in found:
+                if valid_ip_format(ip, text):
+                    valid_ips.append(ip)
+            text_chunks.update([iocextract.refang_ipv4(x) for x in valid_ips])
+        except Exception:
+            pass
     if "email" in iocs_to_parse:
         found = list(iocextract.extract_emails(text, refang=False))
         text_chunks.update(found)
@@ -335,6 +342,7 @@ def parse_iocs(text, defang=False, whitelist_regex='', iocs_to_parse=None,
     if defang:
         result = _defang_results(result)
 
+    result.get('filename', []).extend(filenames)
     return result
 
 
@@ -367,3 +375,34 @@ def type_ioc(ioc, types_to_find=None):
             if IOC_PATTERNS[pat_name].run(ioc):
                 return pat_name
     return "unknown"
+
+def valid_ip_format(ip, text):
+    
+    # Negative lookbehind and lookahead to ensure no alphabetic characters before or after the ip address
+    bounded_pattern = r'(?<![a-zA-Z])' + ip + r'(?![a-zA-Z])'
+    matches = re.finditer(bounded_pattern, text)
+    for match in matches:
+        return True
+    return False
+
+def format_text_without_filepaths(text):
+    # Regex pattern to match Windows file paths
+    # Regex pattern supports multiple slashes (it can occur when file paths are stringified)
+    file_path_pattern = re.compile(
+    r'([a-zA-Z]:\\+(?:[^\\/:*?"<>|\r\n]+\\+)*[^\\/:*?"<>|\r\n]+\.[\w]+)'
+    )
+    
+    # Regex pattern to split based on one or more backslashes
+    split_pattern = re.compile(r'[\\]+')
+    
+    # Find all file paths in the text and extract filenames
+    filenames = []
+    for match in file_path_pattern.finditer(text):
+        file_path = match.group(0)
+        
+        filename = re.split(split_pattern, file_path)[-1]
+        filenames.append(filename)
+
+    # Replace all file paths in the text with an empty string
+    cleaned_text = file_path_pattern.sub('', text)
+    return cleaned_text, filenames
\ No newline at end of file
